@@ -136,9 +136,6 @@ public:
     virtual void pause ();
     virtual void unpause ();
 
-    //Request request;
-    bool ignore_pause;
-
 protected:
     ~AudioVideoActor ();
 };
