@@ -70,6 +70,7 @@ typedef struct _Application {
     GtkToolItem *tb_go;
     GtkToolItem *tb_open;
     GtkToolItem *tb_progress;
+    GtkToolItem *tb_favorites;
     GtkToolItem *video_title;
     GtkWidget *video_jump;
     GtkWidget *video_stop;
@@ -106,6 +107,7 @@ typedef struct _Application {
     bool in_tree_update; /* no events when updating*/
     bool fullscreen;
     bool top_most_window;
+    bool show_playlist;
     int playing;
     guint controls_timer;
     guint title_timer;
@@ -122,6 +124,7 @@ void cb_row_activated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColu
 void cb_playlist_edit_commit (GtkButton * button, Application * app);
 void cb_openUrls (void *app, int argc, gchar **argv);
 void cb_view_area_realized (GtkWidget *widget, Application * app);
+void videoStopRealized (GtkWidget *widget, gpointer p);
 gboolean cb_view_area_expose (GtkWidget *widget, GdkEventExpose *event, Application * app);
 void cb_view_area_configure (GtkWidget *widget, GdkEventConfigure *event, Application * app);
 void cb_view_area_button_press (GtkWidget *widget, GdkEventButton *event, Application * app);
@@ -138,10 +141,10 @@ void cb_playlist_prev (GtkButton * button, void *ctr);
 void cb_playlist_play (GtkButton * button, void *ctr);
 void cb_playlist_next (GtkButton * button, void *ctr);
 void cb_playlist_stop (GtkButton * button, void *ctr);
+void cb_favorites_add (GtkButton *, Application *app);
 gboolean playlist_selected (Application *app, GValue *icon, GValue *text);
 void collapseSelectedList (Application *app);
 void expandSelectedList (Application *app);
-void cb_favorites_add (Application *app);
 void progressValueChanged(GtkWidget *w, Application * app);
 gboolean cb_scheduledPaint (void * p);
 void cbPluginAdded (GtkSocket *socket, Application *app);
