@@ -731,6 +731,7 @@ void Control::stateElementChanged (Node* n, Node::State os, Node::State ns) {
             app_set_playing (m_app, PLAYING);
         }
         if (n->id == SMIL::id_node_body) {
+            m_app->show_playlist = false;
             videoDetected ();
             updateViewAreaSizes (); // move away video widget
         }
@@ -961,6 +962,7 @@ Application *app_new () {
     Application *app = new Application;
     memset (app, 0, sizeof (Application));
     app->control = new Control (app);
+    app->show_playlist = true;
     StringPool::init();
     app->viewarea = new ViewArea (app);
     app->top_most_window = true;
@@ -1065,6 +1067,7 @@ void cbPluginAdded (GtkSocket *socket, Application *app) {
 #ifdef __ARMEL__
     Control *ctr = CONTROL(app);
     debugLog () << "plugin embedded\n";
+    app->show_playlist = false;
     ctr->videoDetected ();
     ((NpPlayer *)ctr->npp)->pluginEmbedded ();
 #endif
@@ -1109,7 +1112,7 @@ void cb_playlist_stop (GtkButton * button, void *p) {
     }
 }
 
-void cb_favorites_add (Application *app) {
+void cb_favorites_add (GtkButton *, Application *app) {
     Control *ctr = CONTROL(app);
     bool valid = false;
     const gchar *msg = "Unknown failure";
